package com.yanzhu.jh.flow.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.flow.mapper.FlowLabourAuditNodeMapper;
import com.yanzhu.jh.flow.domain.FlowLabourAuditNode;
import com.yanzhu.jh.flow.service.IFlowLabourAuditNodeService;
import com.ruoyi.common.utils.SecurityUtils;
/**
 * 劳资投诉审批节点Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2024-04-20
 */
@Service
public class FlowLabourAuditNodeServiceImpl implements IFlowLabourAuditNodeService 
{
    @Autowired
    private FlowLabourAuditNodeMapper flowLabourAuditNodeMapper;

    /**
     * 查询劳资投诉审批节点
     * 
     * @param id 劳资投诉审批节点主键
     * @return 劳资投诉审批节点
     */
    @Override
    public FlowLabourAuditNode selectFlowLabourAuditNodeById(Long id)
    {
        return flowLabourAuditNodeMapper.selectFlowLabourAuditNodeById(id);
    }

    /**
     * 查询劳资投诉审批节点列表
     * 
     * @param flowLabourAuditNode 劳资投诉审批节点
     * @return 劳资投诉审批节点
     */
    @Override
    public List<FlowLabourAuditNode> selectFlowLabourAuditNodeList(FlowLabourAuditNode flowLabourAuditNode)
    {
        return flowLabourAuditNodeMapper.selectFlowLabourAuditNodeList(flowLabourAuditNode);
    }

    /**
     * 新增劳资投诉审批节点
     * 
     * @param flowLabourAuditNode 劳资投诉审批节点
     * @return 结果
     */
    @Override
    public int insertFlowLabourAuditNode(FlowLabourAuditNode flowLabourAuditNode)
    {
        flowLabourAuditNode.setCreateTime(DateUtils.getNowDate());
        return flowLabourAuditNodeMapper.insertFlowLabourAuditNode(flowLabourAuditNode);
    }

    /**
     * 修改劳资投诉审批节点
     * 
     * @param flowLabourAuditNode 劳资投诉审批节点
     * @return 结果
     */
    @Override
    public int updateFlowLabourAuditNode(FlowLabourAuditNode flowLabourAuditNode)
    {
        flowLabourAuditNode.setUpdateBy(SecurityUtils.getUsername());
        flowLabourAuditNode.setUpdateTime(DateUtils.getNowDate());
        return flowLabourAuditNodeMapper.updateFlowLabourAuditNode(flowLabourAuditNode);
    }

    /**
     * 批量删除劳资投诉审批节点
     * 
     * @param ids 需要删除的劳资投诉审批节点主键
     * @return 结果
     */
    @Override
    public int deleteFlowLabourAuditNodeByIds(Long[] ids)
    {
        return flowLabourAuditNodeMapper.deleteFlowLabourAuditNodeByIds(ids);
    }

    /**
     * 删除劳资投诉审批节点信息
     * 
     * @param id 劳资投诉审批节点主键
     * @return 结果
     */
    @Override
    public int deleteFlowLabourAuditNodeById(Long id)
    {
        return flowLabourAuditNodeMapper.deleteFlowLabourAuditNodeById(id);
    }
}
