package com.yanzhu.jh.flow.service.impl;

import java.util.Date;
import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.yanzhu.jh.flow.domain.FlowLabourAuditNode;
import com.yanzhu.jh.flow.mapper.FlowLabourAuditNodeMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.flow.mapper.FlowLabourInfoMapper;
import com.yanzhu.jh.flow.domain.FlowLabourInfo;
import com.yanzhu.jh.flow.service.IFlowLabourInfoService;
import com.ruoyi.common.utils.SecurityUtils;
/**
 * 劳资投诉Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2024-04-19
 */
@Service
public class FlowLabourInfoServiceImpl implements IFlowLabourInfoService 
{
    @Autowired
    private FlowLabourInfoMapper flowLabourInfoMapper;

    @Autowired
    private FlowLabourAuditNodeMapper flowLabourAuditNodeMapper;

    /**
     * 查询劳资投诉
     * 
     * @param id 劳资投诉主键
     * @return 劳资投诉
     */
    @Override
    public FlowLabourInfo selectFlowLabourInfoById(Long id)
    {
        return flowLabourInfoMapper.selectFlowLabourInfoById(id);
    }

    /**
     * 查询劳资投诉列表
     * 
     * @param flowLabourInfo 劳资投诉
     * @return 劳资投诉
     */
    @Override
    public List<FlowLabourInfo> selectFlowLabourInfoList(FlowLabourInfo flowLabourInfo)
    {
        return flowLabourInfoMapper.selectFlowLabourInfoList(flowLabourInfo);
    }

    /**
     * 新增劳资投诉
     * 
     * @param flowLabourInfo 劳资投诉
     * @return 结果
     */
    @Override
    public AjaxResult insertFlowLabourInfo(FlowLabourInfo flowLabourInfo)
    {
        //查询是否已有投诉中的问题
        FlowLabourInfo searchModel = new FlowLabourInfo();
        searchModel.setLaborCardId(flowLabourInfo.getLaborCardId());
        searchModel.setActiveName("MyAwait");
        List<FlowLabourInfo> list = flowLabourInfoMapper.selectFlowLabourInfoList(searchModel);
        if(StringUtils.isNotEmpty(list)){
            flowLabourInfo.setId(0L);
            return AjaxResult.success(flowLabourInfo);
        }else{
            flowLabourInfo.setCreateTime(DateUtils.getNowDate());
            flowLabourInfoMapper.insertFlowLabourInfo(flowLabourInfo);
            //保存流程节点信息
            FlowLabourAuditNode flowLabourAuditNode = new FlowLabourAuditNode();
            flowLabourAuditNode.setFlowId(flowLabourInfo.getId());
            flowLabourAuditNode.setFlowNode("10");
            flowLabourAuditNode.setCreateBy(flowLabourInfo.getLaborName());
            flowLabourAuditNode.setCreateTime(new Date());
            flowLabourAuditNodeMapper.insertFlowLabourAuditNode(flowLabourAuditNode);
            return AjaxResult.success(flowLabourInfo);
        }
    }

    /**
     * 修改劳资投诉
     * 
     * @param flowLabourInfo 劳资投诉
     * @return 结果
     */
    @Override
    public int updateFlowLabourInfo(FlowLabourInfo flowLabourInfo)
    {
        flowLabourInfo.setUpdateBy(SecurityUtils.getUsername());
        flowLabourInfo.setUpdateTime(DateUtils.getNowDate());
        return flowLabourInfoMapper.updateFlowLabourInfo(flowLabourInfo);
    }

    /**
     * 批量删除劳资投诉
     * 
     * @param ids 需要删除的劳资投诉主键
     * @return 结果
     */
    @Override
    public int deleteFlowLabourInfoByIds(Long[] ids)
    {
        return flowLabourInfoMapper.deleteFlowLabourInfoByIds(ids);
    }

    /**
     * 删除劳资投诉信息
     * 
     * @param id 劳资投诉主键
     * @return 结果
     */
    @Override
    public int deleteFlowLabourInfoById(Long id)
    {
        return flowLabourInfoMapper.deleteFlowLabourInfoById(id);
    }
}
